==> embygram-2025.7.27-py3-none-any.whl: pyrogram/types/messages_and_media/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from .animation import Animation
from .audio import Audio
from .available_effect import AvailableEffect
from .boosts_status import BoostsStatus
from .business_message import BusinessMessage
from .chat_background import ChatBackground
from .chat_boost import ChatBoost
from .chat_theme import ChatTheme
from .checked_gift_code import CheckedGiftCode
from .checklist_task import ChecklistTask
from .checklist_tasks_added import ChecklistTasksAdded
from .checklist_tasks_done import ChecklistTasksDone
from .checklist import Checklist
from .contact_registered import ContactRegistered
from .contact import Contact
from .dice import Dice
from .direct_message_price_changed import DirectMessagePriceChanged
from .direct_topic import DirectMessagesTopic
from .document import Document
from .external_reply_info import ExternalReplyInfo
from .fact_check import FactCheck
from .formatted_text import FormattedText
from .forum_topic import ForumTopic
from .forum_topic_closed import ForumTopicClosed
from .forum_topic_created import ForumTopicCreated
from .forum_topic_edited import ForumTopicEdited
from .forum_topic_reopened import ForumTopicReopened
from .game import Game
from .general_forum_topic_hidden import GeneralForumTopicHidden
from .general_forum_topic_unhidden import GeneralForumTopicUnhidden
from .gift_code import GiftCode
from .gift_upgrade_preview import GiftUpgradePreview
from .invoice import Invoice
from .link_preview_options import LinkPreviewOptions
from .giveaway import Giveaway
from .input_checklist_task import InputChecklistTask
from .giveaway_completed import GiveawayCompleted
from .giveaway_created import GiveawayCreated
from .giveaway_prize_stars import GiveawayPrizeStars
from .giveaway_winners import GiveawayWinners
from .location import Location
from .mask_position import MaskPosition
from .media_area import MediaArea
from .message import Message
from .message_entity import MessageEntity
from .message_origin import MessageOrigin
from .message_origin_channel import MessageOriginChannel
from .message_origin_chat import MessageOriginChat
from .message_origin_hidden_user import MessageOriginHiddenUser
from .message_origin_import import MessageOriginImport
from .message_origin_user import MessageOriginUser
from .message_reactions import MessageReactions
from .my_boost import MyBoost
from .paid_media_info import PaidMediaInfo
from .paid_media_preview import PaidMediaPreview
from .paid_messages_price_changed import PaidMessagesPriceChanged
from .paid_messages_refunded import PaidMessagesRefunded
from .paid_reactor import PaidReactor
from .payment_form import PaymentForm
from .payment_option import PaymentOption
from .payment_result import PaymentResult
from .photo import Photo
from .poll import Poll
from .proximity_alert_triggered import ProximityAlertTriggered
from .poll_option import PollOption
from .reaction import Reaction
from .refunded_payment import RefundedPayment
from .reply_parameters import ReplyParameters
from .restriction_reason import RestrictionReason
from .saved_credentials import SavedCredentials
from .screenshot_taken import ScreenshotTaken
from .gift_attribute import GiftAttribute
from .gift import Gift
from .gifted_premium import GiftedPremium
from .gifted_stars import GiftedStars
from .sticker import Sticker
from .story_view import StoryView
from .story import Story
from .stripped_thumbnail import StrippedThumbnail
from .successful_payment import SuccessfulPayment
from .text_quote import TextQuote
from .thumbnail import Thumbnail
from .upgraded_gift_attribute_id_backdrop import UpgradedGiftAttributeIdBackdrop
from .upgraded_gift_attribute_id_model import UpgradedGiftAttributeIdModel
from .upgraded_gift_attribute_id_symbol import UpgradedGiftAttributeIdSymbol
from .upgraded_gift_attribute_id import UpgradedGiftAttributeId
from .venue import Venue
from .video import Video
from .video_note import VideoNote
from .voice import Voice
from .web_app_data import WebAppData
from .web_page import WebPage
from .write_access_allowed import WriteAccessAllowed

__all__ = [
    "Animation",
    "Audio",
    "AvailableEffect",
    "BoostsStatus",
    "BusinessMessage",
    "ChatBackground",
    "ChatBoost",
    "ChatTheme",
    "CheckedGiftCode",
    "ChecklistTask",
    "ChecklistTasksAdded",
    "ChecklistTasksDone",
    "Checklist",
    "ContactRegistered",
    "Contact",
    "Dice",
    "DirectMessagePriceChanged",
    "DirectMessagesTopic",
    "Document",
    "ExternalReplyInfo",
    "FactCheck",
    "FormattedText",
    "ForumTopic",
    "ForumTopicClosed",
    "ForumTopicCreated",
    "ForumTopicEdited",
    "ForumTopicReopened",
    "Game",
    "GeneralForumTopicHidden",
    "GeneralForumTopicUnhidden",
    "GiftCode",
    "GiftUpgradePreview",
    "Giveaway",
    "InputChecklistTask",
    "Invoice",
    "LinkPreviewOptions",
    "GiveawayCompleted",
    "GiveawayCreated",
    "GiveawayPrizeStars",
    "GiveawayWinners",
    "Location",
    "MaskPosition",
    "MediaArea",
    "Message",
    "MessageEntity",
    "MessageOrigin",
    "MessageOriginChannel",
    "MessageOriginChat",
    "MessageOriginHiddenUser",
    "MessageOriginImport",
    "MessageOriginUser",
    "MessageReactions",
    "MyBoost",
    "PaidMediaInfo",
    "PaidMediaPreview",
    "PaidMessagesPriceChanged",
    "PaidMessagesRefunded",
    "PaidReactor",
    "PaymentForm",
    "PaymentOption",
    "PaymentResult",
    "Photo",
    "Poll",
    "ProximityAlertTriggered",
    "PollOption",
    "Reaction",
    "RefundedPayment",
    "ReplyParameters",
    "RestrictionReason",
    "SavedCredentials",
    "ScreenshotTaken",
    "GiftAttribute",
    "Gift",
    "GiftedPremium",
    "GiftedStars",
    "Sticker",
    "StoryView",
    "Story",
    "StrippedThumbnail",
    "SuccessfulPayment",
    "TextQuote",
    "Thumbnail",
    "UpgradedGiftAttributeIdBackdrop",
    "UpgradedGiftAttributeIdModel",
    "UpgradedGiftAttributeIdSymbol",
    "UpgradedGiftAttributeId",
    "Venue",
    "Video",
    "VideoNote",
    "Voice",
    "WebAppData",
    "WebPage",
    "WriteAccessAllowed",
]

==> embygram-2025.9.17-py3-none-any.whl: pyrogram/types/messages_and_media/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from .animation import Animation
from .audio import Audio
from .available_effect import AvailableEffect
from .boosts_status import BoostsStatus
from .business_message import BusinessMessage
from .chat_background import ChatBackground
from .chat_boost import ChatBoost
from .chat_theme import ChatTheme
from .checked_gift_code import CheckedGiftCode
from .checklist_task import ChecklistTask
from .checklist_tasks_added import ChecklistTasksAdded
from .checklist_tasks_done import ChecklistTasksDone
from .checklist import Checklist
from .contact_registered import ContactRegistered
from .contact import Contact
from .dice import Dice
from .direct_message_price_changed import DirectMessagePriceChanged
from .direct_messages_topic import DirectMessagesTopic
from .document import Document
from .external_reply_info import ExternalReplyInfo
from .fact_check import FactCheck
from .formatted_text import FormattedText
from .forum_topic import ForumTopic
from .forum_topic_closed import ForumTopicClosed
from .forum_topic_created import ForumTopicCreated
from .forum_topic_edited import ForumTopicEdited
from .forum_topic_reopened import ForumTopicReopened
from .game import Game
from .general_forum_topic_hidden import GeneralForumTopicHidden
from .general_forum_topic_unhidden import GeneralForumTopicUnhidden
from .gift_collection import GiftCollection
from .gift_code import GiftCode
from .gift_purchase_limit import GiftPurchaseLimit
from .gift_resale_parameters import GiftResaleParameters
from .gift_resale_price import GiftResalePrice, GiftResalePriceStar, GiftResalePriceTon
from .gift_upgrade_preview import GiftUpgradePreview
from .invoice import Invoice
from .link_preview_options import LinkPreviewOptions
from .giveaway import Giveaway
from .input_checklist_task import InputChecklistTask
from .giveaway_completed import GiveawayCompleted
from .giveaway_created import GiveawayCreated
from .giveaway_prize_stars import GiveawayPrizeStars
from .giveaway_winners import GiveawayWinners
from .location import Location
from .mask_position import MaskPosition
from .media_area import MediaArea
from .message import Message
from .message_entity import MessageEntity
from .message_origin import MessageOrigin
from .message_origin_channel import MessageOriginChannel
from .message_origin_chat import MessageOriginChat
from .message_origin_hidden_user import MessageOriginHiddenUser
from .message_origin_import import MessageOriginImport
from .message_origin_user import MessageOriginUser
from .message_reactions import MessageReactions
from .my_boost import MyBoost
from .paid_media_info import PaidMediaInfo
from .paid_media_preview import PaidMediaPreview
from .paid_messages_price_changed import PaidMessagesPriceChanged
from .paid_messages_refunded import PaidMessagesRefunded
from .paid_reactor import PaidReactor
from .payment_form import PaymentForm
from .payment_option import PaymentOption
from .payment_result import PaymentResult
from .photo import Photo
from .poll import Poll
from .proximity_alert_triggered import ProximityAlertTriggered
from .poll_option import PollOption
from .reaction import Reaction
from .refunded_payment import RefundedPayment
from .reply_parameters import ReplyParameters
from .restriction_reason import RestrictionReason
from .saved_credentials import SavedCredentials
from .screenshot_taken import ScreenshotTaken
from .star_amount import StarAmount
from .gift_attribute import GiftAttribute
from .gift import Gift
from .gifted_premium import GiftedPremium
from .gifted_stars import GiftedStars
from .gifted_ton import GiftedTon
from .sticker import Sticker
from .story_view import StoryView
from .story import Story
from .stripped_thumbnail import StrippedThumbnail
from .successful_payment import SuccessfulPayment
from .suggested_post_approval_failed import SuggestedPostApprovalFailed
from .suggested_post_approved import SuggestedPostApproved
from .suggested_post_declined import SuggestedPostDeclined
from .suggested_post_info import SuggestedPostInfo
from .suggested_post_paid import SuggestedPostPaid
from .suggested_post_parameters import SuggestedPostParameters
from .suggested_post_refunded import SuggestedPostRefunded
from .suggested_post_price import SuggestedPostPrice, SuggestedPostPriceStar, SuggestedPostPriceTon
from .text_quote import TextQuote
from .thumbnail import Thumbnail
from .upgraded_gift_attribute_id_backdrop import UpgradedGiftAttributeIdBackdrop
from .upgraded_gift_attribute_id_model import UpgradedGiftAttributeIdModel
from .upgraded_gift_attribute_id_symbol import UpgradedGiftAttributeIdSymbol
from .upgraded_gift_attribute_id import UpgradedGiftAttributeId
from .upgraded_gift_value_info import UpgradedGiftValueInfo
from .venue import Venue
from .video import Video
from .video_note import VideoNote
from .voice import Voice
from .web_app_data import WebAppData
from .web_page import WebPage
from .write_access_allowed import WriteAccessAllowed

__all__ = [
    "Animation",
    "Audio",
    "AvailableEffect",
    "BoostsStatus",
    "BusinessMessage",
    "ChatBackground",
    "ChatBoost",
    "ChatTheme",
    "CheckedGiftCode",
    "ChecklistTask",
    "ChecklistTasksAdded",
    "ChecklistTasksDone",
    "Checklist",
    "ContactRegistered",
    "Contact",
    "Dice",
    "DirectMessagePriceChanged",
    "DirectMessagesTopic",
    "Document",
    "ExternalReplyInfo",
    "FactCheck",
    "FormattedText",
    "ForumTopic",
    "ForumTopicClosed",
    "ForumTopicCreated",
    "ForumTopicEdited",
    "ForumTopicReopened",
    "Game",
    "GeneralForumTopicHidden",
    "GeneralForumTopicUnhidden",
    "GiftCollection",
    "GiftCode",
    "GiftPurchaseLimit",
    "GiftResaleParameters",
    "GiftResalePrice",
    "GiftResalePriceStar",
    "GiftResalePriceTon",
    "GiftUpgradePreview",
    "Giveaway",
    "InputChecklistTask",
    "Invoice",
    "LinkPreviewOptions",
    "GiveawayCompleted",
    "GiveawayCreated",
    "GiveawayPrizeStars",
    "GiveawayWinners",
    "Location",
    "MaskPosition",
    "MediaArea",
    "Message",
    "MessageEntity",
    "MessageOrigin",
    "MessageOriginChannel",
    "MessageOriginChat",
    "MessageOriginHiddenUser",
    "MessageOriginImport",
    "MessageOriginUser",
    "MessageReactions",
    "MyBoost",
    "PaidMediaInfo",
    "PaidMediaPreview",
    "PaidMessagesPriceChanged",
    "PaidMessagesRefunded",
    "PaidReactor",
    "PaymentForm",
    "PaymentOption",
    "PaymentResult",
    "Photo",
    "Poll",
    "ProximityAlertTriggered",
    "PollOption",
    "Reaction",
    "RefundedPayment",
    "ReplyParameters",
    "RestrictionReason",
    "SavedCredentials",
    "ScreenshotTaken",
    "StarAmount",
    "GiftAttribute",
    "Gift",
    "GiftedPremium",
    "GiftedStars",
    "GiftedTon",
    "Sticker",
    "StoryView",
    "Story",
    "StrippedThumbnail",
    "SuccessfulPayment",
    "SuggestedPostInfo",
    "SuggestedPostApprovalFailed",
    "SuggestedPostApproved",
    "SuggestedPostDeclined",
    "SuggestedPostRefunded",
    "SuggestedPostPaid",
    "SuggestedPostParameters",
    "SuggestedPostPrice",
    "SuggestedPostPriceStar",
    "SuggestedPostPriceTon",
    "TextQuote",
    "Thumbnail",
    "UpgradedGiftAttributeIdBackdrop",
    "UpgradedGiftAttributeIdModel",
    "UpgradedGiftAttributeIdSymbol",
    "UpgradedGiftAttributeId",
    "UpgradedGiftValueInfo",
    "Venue",
    "Video",
    "VideoNote",
    "Voice",
    "WebAppData",
    "WebPage",
    "WriteAccessAllowed",
]
